==> haskell-enclosed-exceptions-1.0.2-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.2
id: enclosed-exceptions-1.0.2-6cfMKBmEmYDHbSuMLOmCVB
key: enclosed-exceptions-1.0.2-6cfMKBmEmYDHbSuMLOmCVB
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
abi: bb195793ba1a59a6d01e8903078809e1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/enclosed-exceptions-1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/enclosed-exceptions-1.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/enclosed-exceptions-1.0.2
hs-libraries: HSenclosed-exceptions-1.0.2-6cfMKBmEmYDHbSuMLOmCVB
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    lifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
    monad-control-1.0.2.0-4qPEnRApnc4gRDkIzJcM5 transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.2-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.2
id: enclosed-exceptions-1.0.2-ETmtG4jlkne7UzxeWZik5c
key: enclosed-exceptions-1.0.2-ETmtG4jlkne7UzxeWZik5c
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
author: Michael Snoyman, João Cristóvão
exposed: True
exposed-modules:
    Control.Exception.Enclosed
abi: e5f8fc388685968b5f9a85c79f1423b2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/enclosed-exceptions-1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/enclosed-exceptions-1.0.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/enclosed-exceptions-1.0.2
hs-libraries: HSenclosed-exceptions-1.0.2-ETmtG4jlkne7UzxeWZik5c
depends:
    base-4.9.1.0 deepseq-1.4.2.0
    lifted-base-0.2.3.11-797F0GSRM4GHiCBSQ3AJmQ
    monad-control-1.0.2.0-10S0ywqdsCPHnUTlxJLEct transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
